// Importing modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
// Assigning X axis data   
  const xValue = d => d.population; 
  const xAxisLabel = 'state';
// Assigning Y axis data 
  const yValue = d => d.population;
  const yAxisLabel = 'population';
  
  const margin = { top: 40, right: 20, bottom: 38, left: 130 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
  //  Scale for X axis
  const xScale = scaleTime(
  ).domain([0, max(data, xValue )])
    .range([0, innerWidth]); //round values out
  
//  Scale for Y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// Placing the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line
//adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading CSV data
csv('https://gist.githubusercontent.com/Gayathri-25/bd25fe1e9600b1fa70984138f77a89cf/raw/e1dc55f9bb277c69aafe93da0b2acfa578d1d318/gistfile1.txt')
  .then(data => {
    data.forEach(d => {
    	d.population = +d.population;
//Formatting to retrieve year from the date
      d.population = +d.population;
    });

    render(data);
  })